Full run with witness blocks completed. This run hashes only the block headers and each transaction using the legacy hash function (witnessed hash is different). These are used for index keying.
Measured at block 780,000... The run took an extra 15 minutes (10.74 vs. 10.48) and the store was byte size and object count identical to the previous run until the first witness block, at which point input, puts and total archive sizes all increase, as expected. Store size increased from 388 to 487GB (+99GB). That was a lot more for witness data than I expected, and has accelerated.
The run did however remove the inflection in the graph that started at segwit...